@@ -10,7 +10,7 @@ def cylinder_full(r=None, d=None, le=None, v=None, s=None, rho=None, m=None,
                          'rho': 'kg/m³', 'm': 'kg', 'ix': 'kg·m²',
                          'iy': 'kg·m²', 'iz': 'kg·m²'},
                   calc_mode='values'):
-    """ Returns all cylinder properties for any given set of inputs
+    """ Returns all cylinder properties for any given set of inputs.
 
     Args:
         r (float): Radius.
@@ -72,6 +72,7 @@ def hollow_cylinder(ro=None, ri=None, do=None, di=None, t=None, le=None,
         ri (float): Inner radius.
         do (float): Outer Diameter.
         di (float): Inner diameter.
+        t (float): Wall thickness.
         le (float): Length.
         ix (float): Moment of inertia about x axis.
         iy (float): Moment of inertia about y axis.
@@ -260,19 +261,20 @@ def sphere(r=None, d=None, ix=None, iy=None, iz=None, v=None, rho=None, m=None,
     return result
 
 
-def hollow_sphere(R=None, r=None, D=None, d=None, ix=None, iy=None, iz=None,
-                  v=None, rho=None, m=None, s=None,
-                  units={'R': 'm', 'r': 'm', 'D': 'm', 'd': 'm', 'ix': 'kg·m²',
-                         'iy': 'kg·m²', 'iz': 'kg·m²', 'v': 'm³',
-                         'rho': 'kg/m³', 'm': 'kg', 's': 'm²'},
+def hollow_sphere(ro=None, ri=None, do=None, di=None, ix=None, iy=None,
+                  iz=None, v=None, rho=None, m=None, s=None, t=None,
+                  units={'ro': 'm', 'ri': 'm', 'do': 'm', 'di': 'm',
+                         'iy': 'kg·m²', 'iz': 'kg·m²', 'v': 'm³', 't': 'm',
+                         'rho': 'kg/m³', 'm': 'kg', 's': 'm²', 'ix': 'kg·m²'},
                   calc_mode='values'):
     """ Returns all hollow sphere properties for any given set of inputs
 
     Args:
-        R (float): Outer Radius.
-        r (float): Inner radius.
-        D (float): Outer Diameter.
-        d (float): Inner diameter.
+        ro (float): Outer radius.
+        ri (float): Inner radius.
+        do (float): Outer diameter.
+        di (float): Inner diameter.
+        t (float): Wall thickness.
         ix (float): Moment of inertia about x axis.
         iy (float): Moment of inertia about y axis.
         iz (float): Moment of inertia about z axis.
@@ -284,21 +286,22 @@ def hollow_sphere(R=None, r=None, D=None, d=None, ix=None, iy=None, iz=None,
             missing numerical values) or 'sets' (to calculate valid input sets
             of variables). Default value is 'values'.
     """
-    eqs = ["D - 2*R",
-           "d - 2*r",
-           "v - (4/3)*pi*(R**3-r**3)",
+    eqs = ["do - 2*ro",
+           "di - 2*ri",
+           "t - (ro - ri)",
+           "v - (4/3)*pi*(ro**3-ri**3)",
            "m - rho*v",
-           "s - 4*pi*R**2",
-           "ix - (2/5)*m*((R**5-r**5)/(R**3-r**3))",
+           "s - 4*pi*ro**2 - 4*pi*ri**2",
+           "ix - (2/5)*m*((ro**5-ri**5)/(ro**3-ri**3))",
            "iy - ix",
            "iz - ix"]
 
-    original_units = {'R': 'm', 'r': 'm', 'D': 'm', 'd': 'm', 's': 'm²',
+    original_units = {'ro': 'm', 'ri': 'm', 'do': 'm', 'di': 'm', 's': 'm²',
                       'rho': 'kg/m³', 'm': 'kg', 'ix': 'kg·m²', 'iy': 'kg·m²',
-                      'iz': 'kg·m²', 'v': 'm³'}
-    default_units = {'R': 'm', 'r': 'm', 'D': 'm', 'd': 'm', 's': 'm²',
+                      'iz': 'kg·m²', 'v': 'm³', 't': 'm'}
+    default_units = {'ro': 'm', 'ri': 'm', 'do': 'm', 'di': 'm', 's': 'm²',
                      'rho': 'kg/m³', 'm': 'kg', 'ix': 'kg·m²', 'iy': 'kg·m²',
-                     'iz': 'kg·m²', 'v': 'm³'}
+                     'iz': 'kg·m²', 'v': 'm³', 't': 'm'}
     used_units = {**default_units, **units}
 
     solver_input = dict_conv(locals(), used_units, original_units, 'input')
